﻿-- 
-- Disable foreign keys
-- 
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;

-- 
-- Set character set the client will use to send SQL statements to the server
--
SET NAMES 'utf8';

-- 
-- Set default database
--
USE PBXCALLDB;

--
-- Definition for table ats
--
DROP TABLE IF EXISTS ats;
CREATE TABLE ats (
  pbxid INT(11) NOT NULL COMMENT 'Идентификатор АТС',
  dname VARCHAR(200) DEFAULT NULL COMMENT 'Название АТС',
  UNIQUE INDEX pbxid (pbxid)
)
ENGINE = MYISAM
AVG_ROW_LENGTH = 47
CHARACTER SET utf8
COLLATE utf8_unicode_ci;

--
-- Definition for table calls
--
DROP TABLE IF EXISTS calls;
CREATE TABLE calls (
  id INT(11) NOT NULL AUTO_INCREMENT,
  pbxid INT(11) DEFAULT NULL,
  timeofcall TIMESTAMP NULL DEFAULT '0000-00-00 00:00:00',
  cd CHAR(20) DEFAULT NULL,
  ext CHAR(20) DEFAULT NULL,
  co CHAR(20) DEFAULT NULL,
  ring INT(11) DEFAULT NULL,
  dialnum CHAR(20) DEFAULT NULL,
  dialname CHAR(20) DEFAULT NULL,
  duration INT(11) DEFAULT 0,
  accode CHAR(20) DEFAULT NULL,
  incoming INT(11) DEFAULT NULL,
  cost FLOAT DEFAULT NULL,
  PRIMARY KEY (id),
  INDEX IX_calls (timeofcall, dialnum, ext),
  INDEX IX_calls_dialnum (dialnum),
  INDEX IX_calls_ext (ext),
  INDEX IX_calls_pbxid (pbxid),
  INDEX IX_calls_timeofcall (timeofcall)
)
ENGINE = MYISAM
AUTO_INCREMENT = 3451571
AVG_ROW_LENGTH = 390
CHARACTER SET utf8
COLLATE utf8_unicode_ci;

--
-- Definition for table conames
--
DROP TABLE IF EXISTS conames;
CREATE TABLE conames (
  ats INT(11) NOT NULL,
  conum INT(11) NOT NULL,
  `desc` VARCHAR(255) BINARY NOT NULL,
  PRIMARY KEY (ats, conum)
)
ENGINE = INNODB
AVG_ROW_LENGTH = 48
CHARACTER SET utf8
COLLATE utf8_bin;

--
-- Definition for table config
--
DROP TABLE IF EXISTS config;
CREATE TABLE config (
  cfgname VARCHAR(20) NOT NULL DEFAULT '',
  cfgvalue VARCHAR(20) DEFAULT NULL,
  PRIMARY KEY (cfgname)
)
ENGINE = MYISAM
AVG_ROW_LENGTH = 24
CHARACTER SET utf8
COLLATE utf8_unicode_ci;

--
-- Definition for table numbes
--
DROP TABLE IF EXISTS numbes;
CREATE TABLE numbes (
  number VARCHAR(20) NOT NULL DEFAULT '' COMMENT 'Телефонный номер',
  dname VARCHAR(200) DEFAULT NULL COMMENT 'Название номера',
  PRIMARY KEY (number),
  INDEX IX_numbes (number, dname),
  INDEX IX_numbes_dname (dname),
  INDEX IX_numbes_number (number)
)
ENGINE = MYISAM
AVG_ROW_LENGTH = 27
CHARACTER SET utf8
COLLATE utf8_unicode_ci;

--
-- Definition for table numclass
--
DROP TABLE IF EXISTS numclass;
CREATE TABLE numclass (
  id INT(11) NOT NULL AUTO_INCREMENT,
  numlike VARCHAR(20) DEFAULT NULL COMMENT 'Выражение класифицирующие номер',
  classname VARCHAR(25) DEFAULT NULL COMMENT 'Наименование класса номера',
  prior INT(11) DEFAULT NULL COMMENT 'Приоритет',
  PRIMARY KEY (id),
  UNIQUE INDEX id (id)
)
ENGINE = MYISAM
AUTO_INCREMENT = 17
AVG_ROW_LENGTH = 30
CHARACTER SET utf8
COLLATE utf8_unicode_ci;

--
-- Definition for table users
--
DROP TABLE IF EXISTS users;
CREATE TABLE users (
  userID INT(11) NOT NULL AUTO_INCREMENT,
  login VARCHAR(200) NOT NULL,
  pass VARCHAR(200) NOT NULL,
  email VARCHAR(20) DEFAULT NULL,
  active TINYINT(1) DEFAULT NULL,
  dname VARCHAR(200) DEFAULT NULL,
  admin TINYINT(1) NOT NULL DEFAULT 0,
  detailedview TINYINT(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (userID),
  UNIQUE INDEX login (login)
)
ENGINE = MYISAM
AUTO_INCREMENT = 12
AVG_ROW_LENGTH = 101
CHARACTER SET utf8
COLLATE utf8_unicode_ci;


INSERT INTO users VALUES
(1, 'admin', 'd033e22ae348aeb5660fc2140aec35850c4da997', NULL, 1, 'Администратор', 1, 1);

DELIMITER $$

--
-- Definition for function numberclass
--
DROP FUNCTION IF EXISTS numberclass$$
CREATE FUNCTION numberclass(number VARCHAR (20))
  RETURNS varchar(25) CHARSET utf8
  SQL SECURITY INVOKER
BEGIN
  RETURN ifnull(
(SELECT classname
 FROM
   (SELECT *
    FROM
      numclass
    ORDER BY
      prior) AS tbl
 WHERE
   number COLLATE utf8_unicode_ci LIKE numlike
 LIMIT
   1), "") COLLATE utf8_unicode_ci;
END
$$

--
-- Definition for function numbername
--
DROP FUNCTION IF EXISTS numbername$$
CREATE FUNCTION numbername(num VARCHAR (20))
  RETURNS varchar(200) CHARSET utf8
  SQL SECURITY INVOKER
BEGIN
  RETURN IFNULL((SELECT
    dname
  FROM
    numbes
  WHERE
    number = num
  LIMIT
    1), num);
END
$$

DELIMITER ;

-- 
-- Enable foreign keys
-- 
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;